summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpmainwindow_view.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /kolourpaint/kpmainwindow_view.cpp
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'kolourpaint/kpmainwindow_view.cpp')
-rw-r--r--kolourpaint/kpmainwindow_view.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kolourpaint/kpmainwindow_view.cpp b/kolourpaint/kpmainwindow_view.cpp
index c90479b0..8be4beb8 100644
--- a/kolourpaint/kpmainwindow_view.cpp
+++ b/kolourpaint/kpmainwindow_view.cpp
@@ -289,7 +289,7 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
// Ordinary flicker is better than the whole view moving
TQPainter p (m_mainView);
p.fillRect (m_mainView->rect (),
- m_scrollView->viewport ()->colorGroup ().background ());
+ m_scrollView->viewport ()->tqcolorGroup ().background ());
}
}
@@ -842,13 +842,13 @@ void kpMainWindow::slotSaveThumbnailGeometry ()
TQRect rect (m_thumbnail->x (), m_thumbnail->y (),
m_thumbnail->width (), m_thumbnail->height ());
#if DEBUG_KP_MAIN_WINDOW
- kdDebug () << "\tthumbnail relative geometry=" << rect << endl;
+ kdDebug () << "\tthumbnail relative tqgeometry=" << rect << endl;
#endif
m_configThumbnailGeometry = mapFromGlobal (rect);
#if DEBUG_KP_MAIN_WINDOW
- kdDebug () << "\tCONFIG: saving thumbnail geometry "
+ kdDebug () << "\tCONFIG: saving thumbnail tqgeometry "
<< m_configThumbnailGeometry
<< endl;
#endif
@@ -1067,11 +1067,11 @@ void kpMainWindow::updateThumbnail ()
kdDebug () << "\tcreating thumbnail" << endl;
#endif
// Read last saved geometry before creating thumbnail & friends
// in case they call notifyThumbnailGeometryChanged()
TQRect thumbnailGeometry = m_configThumbnailGeometry;
#if DEBUG_KP_MAIN_WINDOW
- kdDebug () << "\t\tlast used geometry=" << thumbnailGeometry << endl;
+ kdDebug () << "\t\tlast used tqgeometry=" << thumbnailGeometry << endl;
#endif
m_thumbnail = new kpThumbnail (this, "thumbnail");
@@ -1084,9 +1084,9 @@ void kpMainWindow::updateThumbnail ()
if (!thumbnailGeometry.isEmpty () &&
TQRect (0, 0, width (), height ()).intersects (thumbnailGeometry))
{
- const TQRect geometry = mapToGlobal (thumbnailGeometry);
- m_thumbnail->resize (geometry.size ());
- m_thumbnail->move (geometry.topLeft ());
+ const TQRect tqgeometry = mapToGlobal (thumbnailGeometry);
+ m_thumbnail->resize (tqgeometry.size ());
+ m_thumbnail->move (tqgeometry.topLeft ());
}
else
{
@@ -1101,7 +1101,7 @@ void kpMainWindow::updateThumbnail ()
initialHeight);
#if DEBUG_KP_MAIN_WINDOW
- kdDebug () << "\t\tcreating geometry=" << geometryRect << endl;
+ kdDebug () << "\t\tcreating tqgeometry=" << geometryRect << endl;
#endif
geometryRect = mapToGlobal (geometryRect);
@@ -1067,11 +1067,11 @@ void kpMainWindow::updateThumbnail ()
kdDebug () << "\tcreating thumbnail" << endl;
#endif
- // Read last saved geometry before creating thumbnail & friends
+ // Read last saved tqgeometry before creating thumbnail & friends
// in case they call notifyThumbnailGeometryChanged()
TQRect thumbnailGeometry = m_configThumbnailGeometry;